==> mongodb-src-r3.2.17.tar.gz: mongodb-src-r3.2.17/src/mongo/executor/async_stream_common.cpp <==
/**
 *    Copyright (C) 2015 MongoDB Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#define MONGO_LOG_DEFAULT_COMPONENT ::mongo::logger::LogComponent::kASIO

#include "mongo/platform/basic.h"

#include "mongo/executor/async_stream_common.h"

#include "mongo/util/log.h"

namespace mongo {
namespace executor {

void logCloseFailed(std::error_code ec) {
    invariant(ec);
    log() << "Failed to close stream: " << ec.message();
}

void logCancelFailed(std::error_code ec) {
    invariant(ec);
    log() << "Failed to cancel stream: " << ec.message();
}

void logFailureInSetStreamNonBlocking(std::error_code ec) {
    invariant(ec);
    severe() << "Failed to set non-blocking mode on stream: " << ec.message();
}

void logFailureInSetStreamNoDelay(std::error_code ec) {
    invariant(ec);
    severe() << "Failed to set no-delay mode on stream: " << ec.message();
}

void logUnexpectedErrorInCheckOpen(std::error_code ec) {
    invariant(ec);
    log() << "unexpected error when checking if a stream was open: " << ec.message()
          << ", the only error we expected was EOF";
}


}  // namespace executor
}  // namespace  mongo

==> mongodb-src-r3.4.4.tar.gz: mongodb-src-r3.4.4/src/mongo/executor/async_stream_common.cpp <==
/**
 *    Copyright (C) 2015 MongoDB Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#define MONGO_LOG_DEFAULT_COMPONENT ::mongo::logger::LogComponent::kASIO

#include "mongo/platform/basic.h"

#include "mongo/executor/async_stream_common.h"

#include "mongo/util/log.h"

namespace mongo {
namespace executor {

void logCloseFailed(std::error_code ec) {
    invariant(ec);
    log() << "Failed to close stream: " << ec.message();
}

void logCancelFailed(std::error_code ec) {
    invariant(ec);
    log() << "Failed to cancel stream: " << ec.message();
}

void logFailureInSetStreamNonBlocking(std::error_code ec) {
    invariant(ec);
    severe() << "Failed to set non-blocking mode on stream: " << ec.message();
}

void logFailureInSetStreamNoDelay(std::error_code ec) {
    invariant(ec);
    severe() << "Failed to set no-delay mode on stream: " << ec.message();
}

void logUnexpectedErrorInCheckOpen(std::error_code ec) {
    invariant(ec);
    log() << "unexpected error when checking if a stream was open: " << ec.message()
          << ", the only errors we expect are EOF and network/connection reset";
}


}  // namespace executor
}  // namespace  mongo
